@@ -22,12 +22,12 @@ TOP_OBJECT = "/org/storage/stratis2"
 
 SECTOR_SIZE = 512
 
-FETCH_PROPERTIES_INTERFACE = "org.storage.stratis2.FetchProperties.r1"
+FETCH_PROPERTIES_INTERFACE = "org.storage.stratis2.FetchProperties.r2"
 FILESYSTEM_INTERFACE = "org.storage.stratis2.filesystem"
 POOL_INTERFACE = "org.storage.stratis2.pool.r1"
-BLOCKDEV_INTERFACE = "org.storage.stratis2.blockdev"
+BLOCKDEV_INTERFACE = "org.storage.stratis2.blockdev.r2"
 REPORT_INTERFACE = "org.storage.stratis2.Report.r1"
 
 MAXIMUM_STRATISD_VERSION = "3.0.0"
-MINIMUM_STRATISD_VERSION = "2.1.0"
+MINIMUM_STRATISD_VERSION = "2.2.0"
 assert Version(MINIMUM_STRATISD_VERSION) < Version(MAXIMUM_STRATISD_VERSION)
